-- 	Copyright  2000.	GSI Technology
-- 						Apps@gsitechnology.com
--  v 1.1 01/25/2007 Jeff Duagherty  1) Added -300 Speed bin
--  v 1.0 4/23/2002 Jeff Duagherty  1) based on G16272
LIBRARY ieee;
USE ieee.std_logic_1164.all;
ENTITY G864218B IS	
  GENERIC (
    CONSTANT A_bits      : integer := 14;--  16K per 9 I/O storage
--300MHZ
--    CONSTANT tKQXpipe     : time    := 1.5 ns ;
--    CONSTANT tKQXflow     : time    := 3.0 ns ;
--    CONSTANT tKQpipe     : time    := 2.3 ns ;
--    CONSTANT tKQflow     : time    := 5.5 ns) ;
--250MHZ
--    CONSTANT tKQXpipe     : time    := 1.5 ns ;
--    CONSTANT tKQXflow     : time    := 3.0 ns ;
--    CONSTANT tKQpipe     : time    := 2.5 ns ;
--    CONSTANT tKQflow     : time    := 6.5 ns) ;
--200MHZ
--    CONSTANT tKQXpipe     : time    := 1.5 ns ;
--    CONSTANT tKQXflow     : time    := 3.0 ns ;
--    CONSTANT tKQpipe     : time    := 3.0 ns ;
--    CONSTANT tKQflow     : time    := 7.5 ns) ;
--166MHZ
    CONSTANT tKQXpipe     : time    := 1.5 ns ;
    CONSTANT tKQXflow     : time    := 3.0 ns ;
    CONSTANT tKQpipe     : time    := 3.4 ns ;
    CONSTANT tKQflow     : time    := 8.0 ns) ;
  PORT (
    SIGNAL A864  : IN std_logic_vector(21 DOWNTO 0);-- address
    SIGNAL DQa   : INOUT std_logic_vector(9 DOWNTO 1);-- byte A data
    SIGNAL DQb   : INOUT std_logic_vector(9 DOWNTO 1);-- byte B data
    SIGNAL nBa   : IN std_logic;-- bank A write enable
    SIGNAL nBb   : IN std_logic;-- bank B write enable
    SIGNAL CK    : IN std_logic;-- clock
    SIGNAL nBW   : IN std_logic;-- byte write enable
    SIGNAL nGW   : IN std_logic;-- Global write enable
    SIGNAL nE1   : IN std_logic;-- chip enable 1
    SIGNAL nG    : IN std_logic;-- output enable
    SIGNAL nADV  : IN std_logic;-- Advance not / load
    SIGNAL nADSC : IN std_logic;      -- ONLY FOR BURST DEVICES
    SIGNAL nADSP : IN std_logic;      -- ONLY FOR BURST DEVICES
    SIGNAL ZZ    : IN std_logic;-- power down
    SIGNAL nFT   : IN std_logic;-- Pipeline / Flow through
    SIGNAL nLBO  : IN std_logic;-- Linear Burst Order not
    SIGNAL SCD   : IN std_logic;      -- ONLY FOR BURST DEVICES
    SIGNAL ZQ    : IN std_logic;
    SIGNAL TMS   : IN std_logic;-- Scan Test Mode Select
    SIGNAL TDI   : IN std_logic;-- Scan Test Data In
    SIGNAL TDO   : OUT std_logic;-- Scan Test Data Out
    SIGNAL TCK   : IN std_logic);-- Scan Test Clock
END G864218B;

LIBRARY Std;
ARCHITECTURE BURST_72MEG_x18 OF G864218B IS
  USE Std.textio.ALL;
  component VHDL_BURST_CORE
    generic (
      CONSTANT bank_size   : integer;
      CONSTANT A_size      : integer;
      CONSTANT A_bits      : integer;
      CONSTANT DQ_size     : integer);
    port (
      signal       A           : in    std_logic_vector(A_size - 1 downto 0);  -- address
      signal       DQa         : inout std_logic_vector(DQ_size downto 1);  -- byte A data
      signal       DQb         : inout std_logic_vector(DQ_size downto 1);  -- byte B data
      signal       DQc         : inout std_logic_vector(DQ_size downto 1);  -- byte C data
      signal       DQd         : inout std_logic_vector(DQ_size downto 1);  -- byte D data
      signal       DQe         : inout std_logic_vector(DQ_size downto 1);  -- byte E data
      signal       DQf         : inout std_logic_vector(DQ_size downto 1);  -- byte F data
      signal       DQg         : inout std_logic_vector(DQ_size downto 1);  -- byte G data
      signal       DQh         : inout std_logic_vector(DQ_size downto 1);  -- byte H data
      signal       nBa         : in    std_logic;  -- bank A write enable
      signal       nBb         : in    std_logic;  -- bank B write enable
      signal       nBc         : in    std_logic;  -- bank C write enable
      signal       nBd         : in    std_logic;  -- bank D write enable
      signal       nBe         : in    std_logic;
      signal       nBf         : in    std_logic;
      signal       nBg         : in    std_logic;
      signal       nBh         : in    std_logic;
      signal       CK          : in    std_logic;  -- clock
      signal       nBW         : in    std_logic;  -- byte write enable
      signal       nGW         : in    std_logic;  -- Global write enable
      signal       nE1         : in    std_logic;  -- chip enable 1
      signal       E2          : in    std_logic;  -- chip enable 2
      signal       nE3         : in    std_logic;  -- chip enable 3
      signal       nG          : in    std_logic;  -- output enable
      signal       nADV        : in    std_logic;  -- Advance not / load
      signal       nADSC       : in    std_logic;  -- ONLY FOR BURST DEVICES
      signal       nADSP       : in    std_logic;  -- ONLY FOR BURST DEVICES
      signal       ZZ          : in    std_logic;  -- power down
      signal       nFT         : in    std_logic;  -- Pipeline / Flow through
      signal       nLBO        : in    std_logic;  -- Linear Burst Order not
      signal       SCD         : in    std_logic;  -- ONLY FOR BURST DEVICES
      SIGNAL       HighZ       : std_logic_vector(DQ_size downto 1) ;
      signal       tKQ         :       time;
      signal       tKQX         :       time);
  end component;

  constant bank_size : integer := 2**a_bits;  -- defines Memory_core and Address_core size
  constant DQ_size   : integer := 9;
  constant A_size    : integer := 22;

  SIGNAL E2    : std_logic := '1';-- chip enable 2
  SIGNAL nE3   : std_logic := '0';-- chip enable 3
  SIGNAL nBc   : std_logic := '1';-- bank C write enable
  SIGNAL nBd   : std_logic := '1';-- bank D write enable
  SIGNAL nBe   : std_logic := '1';
  SIGNAL nBf   : std_logic := '1';
  SIGNAL nBg   : std_logic := '1';
  SIGNAL nBh   : std_logic := '1';
  SIGNAL DQc   : std_logic_vector(DQ_size DOWNTO 1);-- byte C data
  SIGNAL DQd   : std_logic_vector(DQ_size DOWNTO 1);-- byte D data
  SIGNAL DQe   : std_logic_vector(DQ_size DOWNTO 1);-- byte E data
  SIGNAL DQf   : std_logic_vector(DQ_size DOWNTO 1);-- byte F data
  SIGNAL DQg   : std_logic_vector(DQ_size DOWNTO 1);-- byte G data
  SIGNAL DQh   : std_logic_vector(DQ_size DOWNTO 1);-- byte H data
  signal tKQ   : time := 1 ns;
  signal tKQX   : time:= 1 ns;
  SIGNAL HighZ : std_logic_vector(DQ_size downto 1) := (others=>'Z');
begin 
  tKQ <= tKQpipe when nFT='1' else tKQflow;
  tKQX <= tKQXpipe when nFT='1' else tKQXflow;
  CORE_CALL : VHDL_BURST_CORE
    generic map (
      bank_size => bank_size,
      A_size    => A_size,
      A_bits    => A_bits,
      DQ_size   => DQ_size)
    port map (A864, DQA, DQB, DQC, DQD, DQE, DQF, DQG, DQH, NBA, NBB, NBC, NBD, NBE, NBF, NBG, NBH, CK, NBW, NGW, NE1, E2, NE3, NG, NADV, NADSC, NADSP, ZZ, NFT, NLBO, SCD, HighZ, tKQ, tKQX);
END BURST_72MEG_x18;
